@@ -18,7 +18,7 @@ def mod_record_map(mod,
             input_list = [e[input_field] for e in input_list]
         else:
             input_list = [getattr(e, input_field) for e in input_list]
-    query_set = mod.select().where([getattr(mod, field).in_ == input_list])
+    query_set = mod.select().where([getattr(mod, field).in_(input_list)])
     return {getattr(e, field): e for e in query_set}
 
 
@@ -43,7 +43,7 @@ def mod_get_in_db_set(mod,
         return getattr(x, field)
     if format is None:
         format = default_format
-    query_set = mod.select().where([getattr(mod, field).in_ == input_list])
+    query_set = mod.select().where([getattr(mod, field).in_(input_list)])
     return {format(x) for x in query_set}
 
 
